summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--remoting/host/capture_scheduler.cc4
1 files changed, 2 insertions, 2 deletions
diff --git a/remoting/host/capture_scheduler.cc b/remoting/host/capture_scheduler.cc
index a4f7efb..4acf384 100644
--- a/remoting/host/capture_scheduler.cc
+++ b/remoting/host/capture_scheduler.cc
@@ -16,8 +16,8 @@ namespace {
// over.
const int kStatisticsWindow = 3;
-// The hard limit is 20fps or 50ms per recording cycle.
-const int64 kMinimumRecordingDelay = 50;
+// The hard limit is 30fps or 33ms per recording cycle.
+const int64 kMinimumRecordingDelay = 33;
// Controls how much CPU time we can use for encode and capture.
// Range of this value is between 0 to 1. 0 means using 0% of of all CPUs